tiled.adapters.xarray.DatasetAdapter
====================================

.. currentmodule:: tiled.adapters.xarray

.. autoclass:: DatasetAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DatasetAdapter.__init__
      ~DatasetAdapter.items
      ~DatasetAdapter.macrostructure
      ~DatasetAdapter.microstructure
      ~DatasetAdapter.read
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DatasetAdapter.metadata
      ~DatasetAdapter.structure_family
   
   